#
# spec file for package python-testresources
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-testresources
Version:        2.0.1
Release:        9.3
Summary:        A pyunit extension for managing expensive test resources
License:        (Apache-2.0 OR BSD-3-Clause) AND GPL-2.0-or-later
URL:            https://github.com/testing-cabal/testresources
Source:         https://files.pythonhosted.org/packages/source/t/testresources/testresources-%{version}.tar.gz
Patch0:         testresources-flaky-tests.patch
# PATCH-FIX-UPSTREAM gh#testing-cabal/testresources#15
Patch1:         use-correct-assertions.patch
BuildRequires:  %{python_module fixtures}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testtools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pbr
BuildArch:      noarch
%python_subpackages

%description
testresources: extensions to python unittest to allow declarative use
of resources by test cases.

%prep
%autosetup -p1 -n testresources-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest

%files %{python_files}
%license BSD Apache-2.0 COPYING
%doc README.rst
%{python_sitelib}/testresources
%{python_sitelib}/testresources-%{version}.dist-info

%changelog
* Wed May  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Do not use pytest for the testsuite, switch to %%pyunittest.
* Wed Aug 16 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-correct-assertions.patch:
  * Use current and correct method names.
- Switch to pyproject macros.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Apr 18 2023 Matej Cepl <mcepl@suse.com>
- Switch to single spec version build for PSP
* Wed Jan 13 2021 pgajdos@suse.com
- use %%pytest macro
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Wed Aug  8 2018 jengelh@inai.de
- Trim repeated name from summary (rpmlint).
* Tue Aug  7 2018 tchvatal@suse.com
- Add patch testresources-flaky-tests.patch to disable flaky test
- Drop PR-8.patch as it is obsolete by the above patch
* Tue Aug  7 2018 tchvatal@suse.com
- Cleanup with spec-cleaner
- Simplify the tests execution
- Install license files
* Thu Sep 21 2017 tbechtold@suse.com
- Add PR-8.patch . This skips a flaky test during python3 test runs
* Sun Apr  9 2017 aloisio@gmx.com
- Converted to single-spec
- Fixed source URL
* Mon Nov 14 2016 dmueller@suse.com
- update to 2.0.1:
  * Fix #1590536 classifiers not reported in PyPI
  * Drop support for Python 2.4, 2.5, 3.2
  * Bug #1524048: depend on pbr at runtime
  * Handle unittest2 test suites as well
  * Use pbr for versions as well
  * More diagnostics on sort failures
  * Cleanup old helper we don't need anymore
  * Add a tox.ini for convenience
  * Add a Travis config
  * Ignore more files
  * Build and ship wheels
  * Migrate to pbr
* Thu Jun 12 2014 cdenicolo@suse.com
- license update: (Apache-2.0 or BSD-3-Clause) and GPL-2.0+
  missing BSD-license
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Apr  3 2013 speilicke@suse.com
- Fix license according to what sr#159597 intended
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
